<?php
/**
 * Brimstone Theme Customizer
 *
 * @package Brimstone
 */

/**
 * Add refresh support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function brimstone_customize_register( $wp_customize ) {
	global $brimstone_default;

	require get_template_directory() . '/inc/class-customize-control.php';

	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname', array(
				'selector'        => '.site-title a',
				'render_callback' => 'brimstone_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription', array(
				'selector'        => '.site-description',
				'render_callback' => 'brimstone_customize_partial_blogdescription',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'custom_logo_2x', array(
				'selector'        => '.site-logo',
				'render_callback' => 'brimstone_customize_partial_custom_logo',
			)
		);
	}

	/**
	 * Logo
	 */
	$section_id = 'title_tagline';

	$setting_id = 'custom_logo_2x';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize, $setting_id, array(
				'label'         => __( 'Retina Logo', 'brimstone' ),
				'priority'      => 8, /* below the logo media selector. */
				'section'       => $section_id,
				'button_labels' => array(
					'select'       => __( 'Select Retina Logo', 'brimstone' ),
					'change'       => __( 'Change Retina Logo', 'brimstone' ),
					'placeholder'  => __( 'No retina logo selected', 'brimstone' ),
					'frame_title'  => __( 'Select Retina Logo', 'brimstone' ),
					'frame_button' => __( 'Choose Retina Logo', 'brimstone' ),
				),
				'description'   => __( 'Select image twice the size as your original logo image for crisp display on retina screens.', 'brimstone' ),
			)
		)
	);

	$setting_id = 'display_site_title';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Display Site Title', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_site_tagline';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Display Site Tagline', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'heading_padding_top';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'number',
			'label'   => __( 'Padding Top', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'heading_padding_bottom';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'number',
			'label'   => __( 'Padding Bottom', 'brimstone' ),
			'section' => $section_id,
		)
	);

	/**
	 * Custom colors.
	 */
	$section_id = 'colors';

	$setting_id = 'primary_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Primary Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'primary_hover_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Primary Hover Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'archive_background_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Archive Background Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'archive_title_light';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Display White Archive Title?', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'footer_background_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Footer Background Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'site_info_background_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Site Info Background Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'footer_text_light';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Display White Footer Text?', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'link_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Link Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = 'link_hover_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Link Hover Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	/**
	 * Theme options.
	 */
	$wp_customize->add_panel(
		'theme_options', array(
			'title'    => __( 'Theme Options', 'brimstone' ),
			'priority' => 330, // Before Additional CSS.
		)
	);

	/**
	 * Site
	 */
	$section_id = 'theme_options_site';
	$wp_customize->add_section(
		$section_id, array(
			'title' => __( 'Site', 'brimstone' ),
			'panel' => 'theme_options',
		)
	);

	$setting_id = 'show_menu_arrows';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Show Menu Arrows', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'default_button_style';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'        => 'select',
			'label'       => __( 'Default Button Style', 'brimstone' ),
			'description' => __( 'When you insert a link on its own line in the WP Editor, the theme turns it into a button. Choose the default style of your button to display in your post and pages.', 'brimstone' ),
			'section'     => $section_id,
			'choices'     => array(
				'default'  => __( 'Default Button', 'brimstone' ),
				'button-1' => __( 'Button Style 1', 'brimstone' ),
				'button-2' => __( 'Button Style 2', 'brimstone' ),
			),
		)
	);

	$setting_id = 'disable_body_font';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'            => 'checkbox',
			'label'           => __( 'Disable Body Font', 'brimstone' ),
			'description'     => __( 'If you are using a Google Font plugin, then you can disable the load of the body font.', 'brimstone' ),
			'section'         => $section_id,
			'active_callback' => 'brimstone_is_wpm_fonts_deactivated',
		)
	);

	$setting_id = 'disable_heading_font';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'            => 'checkbox',
			'label'           => __( 'Disable Heading Font', 'brimstone' ),
			'description'     => __( 'If you are using a Google Font plugin, then you can disable the load of the heading font.', 'brimstone' ),
			'section'         => $section_id,
			'active_callback' => 'brimstone_is_wpm_fonts_deactivated',
		)
	);

	$setting_id = 'disable_accent_font';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'            => 'checkbox',
			'label'           => __( 'Disable Accent Font', 'brimstone' ),
			'description'     => __( 'The accent font is a cursive font used in places such as your archive title. If you are using a Google Font plugin, then you can disable the load of this accent font.', 'brimstone' ),
			'section'         => $section_id,
			'active_callback' => 'brimstone_is_wpm_fonts_deactivated',
		)
	);

	$setting_id = 'page_image_header_height';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'section'     => $section_id,
			'type'        => 'range',
			'label'       => __( 'Page Image Header Height', 'brimstone' ),
			'description' => __( 'This changes the height of your featured image in your page header area.', 'brimstone' ),
			'section'     => $section_id,
			'input_attrs' => array(
				'min'   => 0,
				'max'   => 800,
				'step'  => 5,
				'style' => 'width:100%;',
			),
		)
	);

	$setting_id = 'post_image_header_height';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'section'     => $section_id,
			'type'        => 'range',
			'label'       => __( 'Post Image Header Height', 'brimstone' ),
			'description' => __( 'This changes the height of your featured image in your post header area.', 'brimstone' ),
			'section'     => $section_id,
			'input_attrs' => array(
				'min'   => 0,
				'max'   => 800,
				'step'  => 5,
				'style' => 'width:100%;',
			),
		)
	);

	/**
	 * Blog
	 */
	$section_id = 'theme_options_blog';
	$wp_customize->add_section(
		$section_id, array(
			'title' => __( 'Blog', 'brimstone' ),
			'panel' => 'theme_options',
		)
	);

	$setting_id = 'blog_display';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Blog Display', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				'blog1' => __( 'Lead Excerpt + Grid', 'brimstone' ),
				'blog4' => __( 'Grid', 'brimstone' ),
				'blog2' => __( 'Excerpt', 'brimstone' ),
				'blog3' => __( 'Content', 'brimstone' ),
			),
		)
	);

	$setting_id = 'archive_display';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Archive Display', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				'blog1' => __( 'Lead Excerpt + Grid', 'brimstone' ),
				'blog4' => __( 'Grid', 'brimstone' ),
				'blog2' => __( 'Excerpt', 'brimstone' ),
				'blog3' => __( 'Content', 'brimstone' ),
			),
		)
	);

	$setting_id = 'search_display';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Search Display', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				'blog1' => __( 'Lead Excerpt + Grid', 'brimstone' ),
				'blog4' => __( 'Grid', 'brimstone' ),
				'blog2' => __( 'Excerpt', 'brimstone' ),
				'blog3' => __( 'Content', 'brimstone' ),
			),
		)
	);

	$setting_id = 'thumb_excerpt_max_height';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'section'     => $section_id,
			'type'        => 'number',
			'label'       => __( 'Thumb Excerpt Max Height', 'brimstone' ),
			'description' => __( 'If you have long featured images in your excerpts, set a max-height on your image. Enter 0 for no max-height', 'brimstone' ),
			'section'     => $section_id,
			'input_attrs' => array(
				'min'  => 0,
				'step' => 1,
			),
		)
	);

	$setting_id = 'thumb_grid_max_height';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'section'     => $section_id,
			'type'        => 'number',
			'label'       => __( 'Thumb Grid Max Height', 'brimstone' ),
			'description' => __( 'If you have long featured images in your grid, set a max-height on your image. Enter 0 for no max-height', 'brimstone' ),
			'section'     => $section_id,
			'input_attrs' => array(
				'min'  => 0,
				'step' => 1,
			),
		)
	);

	$setting_id = 'blog_single_hide_post_navigation';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'        => 'checkbox',
			'label'       => __( 'Hide Post Navigation', 'brimstone' ),
			'description' => __( 'Hide the post navigation buttons at the bottom of each post.', 'brimstone' ),
			'section'     => $section_id,
		)
	);

	/**
	 * Jetpack
	 */
	$section_id = 'theme_options_jetpack';
	$wp_customize->add_section(
		$section_id, array(
			'title'           => __( 'Jetpack', 'brimstone' ),
			'panel'           => 'theme_options',
			'active_callback' => 'brimstone_is_jetpack_activated',
		)
	);

	$setting_id = 'jetpack_hide_share_count';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Share Button Count', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'jetpack_scroll_credit';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'wp_kses_post',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'text',
			'label'   => esc_html__( 'Infinite Scroll Credit Text', 'brimstone' ),
			'section' => $section_id,
		)
	);

	/**
	 * Shop
	 */
	$section_id = 'theme_options_shop';
	$wp_customize->add_section(
		$section_id, array(
			'title'           => __( 'Shop', 'brimstone' ),
			'panel'           => 'theme_options',
			'active_callback' => 'brimstone_is_woocommerce_activated',
		)
	);

	$setting_id = 'shop_columns';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Shop Columns', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				2 => __( '2', 'brimstone' ),
				3 => __( '3', 'brimstone' ),
				4 => __( '4', 'brimstone' ),
			),
		)
	);

	$setting_id = 'shop_archive_columns';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Shop Archive Columns', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				2 => __( '2', 'brimstone' ),
				3 => __( '3', 'brimstone' ),
				4 => __( '4', 'brimstone' ),
			),
		)
	);

	$setting_id = 'shop_related_products_columns';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'select',
			'label'   => __( 'Related Products Columns', 'brimstone' ),
			'section' => $section_id,
			'choices' => array(
				2 => __( '2', 'brimstone' ),
				3 => __( '3', 'brimstone' ),
				4 => __( '4', 'brimstone' ),
			),
		)
	);

	$setting_id = 'shop_image_backdrop';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'        => 'checkbox',
			'label'       => __( 'Display Product Image Backdrop', 'brimstone' ),
			'description' => __( 'Add a light gray backdrop with a dropshadow for your product images. Visually helpful for images with light colored backgrounds.', 'brimstone' ),
			'section'     => $section_id,
		)
	);

	$setting_id = 'shop_hide_title';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Shop Title From Main Shop Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_hide_breadcrumbs';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Breadcrumbs From Shop Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_hide_stars';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Product Reviews From Shop Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_hide_result_count';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Result Count String From Shop Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_hide_catalog_ordering';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Ordering Dropdown From Shop Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_truncate_titles';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'        => 'checkbox',
			'label'       => __( 'Truncate Product Titles', 'brimstone' ),
			'description' => __( 'This will cause product titles to appear in one line.', 'brimstone' ),
			'section'     => $section_id,
		)
	);

	$setting_id = 'shop_product_hide_stars';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Product Reviews From Product Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_product_hide_meta';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Hide Product Meta From Product Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_disable_gallery_zoom';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Disable Gallery Zoom on Product Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_disable_gallery_lightbox';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Disable Gallery Lightbox on Product Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'shop_disable_gallery_slider';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Disable Gallery Slider on Product Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	/**
	 * Display Sidebar
	 */
	$section_id = 'theme_options_display_sidebar';
	$wp_customize->add_section(
		$section_id, array(
			'title'       => __( 'Display Sidebar', 'brimstone' ),
			'panel'       => 'theme_options',
			'description' => __( 'Check the pages where you want the sidebar to display.', 'brimstone' ),
		)
	);

	$setting_id = 'display_sidebar_blog';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Blog', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_post';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Post', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_archive';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Archive', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_search';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Search', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_shop';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
			'active_callback'   => 'brimstone_is_woocommerce_activated',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Shop', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_shop_archive';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
			'active_callback'   => 'brimstone_is_woocommerce_activated',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Shop Archive', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'display_sidebar_attachment';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Attachment Page', 'brimstone' ),
			'section' => $section_id,
		)
	);

	/**
	 * Labels
	 */
	$section_id = 'theme_options_lables';
	$wp_customize->add_section(
		$section_id, array(
			'title' => __( 'Labels', 'brimstone' ),
			'panel' => 'theme_options',
		)
	);

	$setting_id = 'mobile_menu_label';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'text',
			'label'   => __( 'Mobile Menu Label', 'brimstone' ),
			'section' => $section_id,
		)
	);

	$setting_id = 'read_more_label';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'text',
			'label'   => __( 'Read More Label', 'brimstone' ),
			'section' => $section_id,
		)
	);

	/**
	 * 404 Error Page
	 */
	$section_id = 'theme_options_404';
	$wp_customize->add_section(
		$section_id, array(
			'title' => __( '404 Error Page', 'brimstone' ),
			'panel' => 'theme_options',
		)
	);

	$setting_id = '404_custom_page';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'label'          => __( 'Select 404 Page', 'brimstone' ),
			'description'    => __( 'Set the page\'s featured image for the background image to display.', 'brimstone' ),
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'section'        => $section_id,
		)
	);

	$setting_id = '404_cover_opacity';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'        => 'range',
			'label'       => __( 'Page Cover Opacity', 'brimstone' ),
			'description' => __( 'Set opacity for 404 Page Cover\'s featured image.', 'brimstone' ),
			'section'     => $section_id,
			'input_attrs' => array(
				'min'   => 0,
				'max'   => 100,
				'step'  => 1,
				'style' => 'width:100%;',
			),
		)
	);

	$setting_id = '404_cover_color';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, $setting_id, array(
				'label'   => __( 'Page Cover Color', 'brimstone' ),
				'section' => $section_id,
			)
		)
	);

	$setting_id = '404_text_white';
	$wp_customize->add_setting(
		$setting_id, array(
			'default'           => $brimstone_default[ $setting_id ],
			'transport'         => 'refresh',
			'sanitize_callback' => 'brimstone_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		$setting_id, array(
			'type'    => 'checkbox',
			'label'   => __( 'Display White Text', 'brimstone' ),
			'section' => $section_id,
		)
	);

	if ( brimstone_is_wpm_fonts_deactivated() ) {
		/**
		 * Fonts
		 */
		$section_id = 'wpm_fonts';
		$wp_customize->add_section(
			$section_id, array(
				'title'    => __( 'Fonts', 'brimstone' ),
				'panel'    => 'theme_options',
				'priority' => 331, // Before Additional CSS.
			)
		);

		$setting_id = 'wpm_fonts_notice';
		$wp_customize->add_setting(
			$setting_id, array(
				'default'           => '',
				'transport'         => 'refresh',
				'sanitize_callback' => 'int',
			)
		);

		$wp_customize->add_control(
			new Brimstone_Notice_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Font Customization', 'brimstone' ),
					'description' => __( 'To easily change the font styles for your theme, please download our <a target="_blank" href="https://webplantmedia.com/product/designer-fonts-wordpress-plugin/"><span style="text-decoration:none;" class="dashicons dashicons-external"></span>Designer Fonts</a> plugin.', 'brimstone' ),
					'section'     => $section_id,
					'settings'    => $setting_id,
				)
			)
		);
	}
}
add_action( 'customize_register', 'brimstone_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function brimstone_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function brimstone_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Render the site logo for the selective refresh partial.
 *
 * @return void
 */
function brimstone_customize_partial_custom_logo() {
	the_custom_logo();
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function brimstone_customize_preview_js() {
	wp_enqueue_script( 'brimstone-customizer', get_template_directory_uri() . '/js/admin/customizer.js', array( 'customize-preview' ), BRIMSTONE_VERSION, true );
	wp_enqueue_script( 'brimstone-admin-notifier', get_template_directory_uri() . '/js/admin/admin-notifier.js', array( 'customize-preview' ), BRIMSTONE_VERSION, true );
	wp_enqueue_style( 'brimstone-customizer-style', get_parent_theme_file_uri() . '/css/admin/customizer.css', array(), BRIMSTONE_VERSION );
}
add_action( 'customize_preview_init', 'brimstone_customize_preview_js' );

/**
 * Sanitize the page layout options.
 *
 * @param string $input Page layout.
 */
function brimstone_sanitize_checkbox( $input ) {
	if ( 1 === intval( $input ) ) {
		return 1;
	}

	return 0;
}
